@@ -13,62 +13,62 @@
         <translation>Desarrolladores principales</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="50"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="52"/>
         <source>A&amp;uthors</source>
         <translation>A&amp;utores</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="54"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="56"/>
         <source>Translation</source>
         <translation>Traducción</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="55"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="57"/>
         <source>Czech</source>
         <translation>Checo</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="56"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="58"/>
         <source>Slovenian</source>
         <translation>Esloveno</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="57"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="59"/>
         <source>French</source>
         <translation>Francés</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="63"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="65"/>
         <source>Logo</source>
         <translation>Logo</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="65"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="67"/>
         <source>Coordinating</source>
         <translation>Coordinación</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="68"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="70"/>
         <source>Testing</source>
         <translation>Pruebas</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="79"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="81"/>
         <source>&amp;Thanks To</source>
         <translation>&amp;Agradecemos a</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="84"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="86"/>
         <source>&amp;Licence Agreement</source>
         <translation>&amp;Licencia</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="86"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="88"/>
         <source>OK</source>
         <translation>Aceptar</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="99"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="101"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
@@ -78,25 +78,30 @@
         <translation>Esta es la aplicación Stopmotion, para crear animaciones de stop motion.</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="58"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="60"/>
         <source>German</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="59"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="61"/>
         <source>Portuguese</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="60"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="62"/>
         <source>Spanish</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="61"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="63"/>
         <source>Swedish</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="50"/>
+        <source>Contributors</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DeviceTab</name>
@@ -285,7 +290,7 @@
 <context>
     <name>Form</name>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="36"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="33"/>
         <source>Form</source>
         <translation>Form</translation>
     </message>
@@ -344,12 +349,12 @@
 <context>
     <name>FrameView</name>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="436"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="444"/>
         <source>Warning</source>
         <translation>Advertencia</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="427"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="435"/>
         <source>Grabbing failed. This may happen if you try
 to grab from an invalid device. Please check
 your grabber settings in the preferences menu.</source>
@@ -358,7 +363,7 @@ capturar desde un dispositivo inválido. Por favor chequee los ajustes
 del capturador en el menú de preferencias.</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="438"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="446"/>
         <source>You have to define an image grabber to use.
 This can be set in the preferences menu.</source>
         <translation>Debe definir un capturador de imágenes a emplear. Éste se puede determinar en el menú de preferencias.</translation>
@@ -369,7 +374,7 @@ This can be set in the preferences menu.</source>
         <translation>El comando de preconsulta no existe</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="382"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="386"/>
         <source>You do not have the given grabber installed on your system</source>
         <translation>El capturador que ha proporcionado no se encuentra instalado en su sistema</translation>
     </message>
@@ -864,15 +869,40 @@ sus ajustes en el menú de preferencias?</translation>
 <context>
     <name>ModelHandler</name>
     <message>
-        <location filename="../src/application/modelhandler.cpp" line="52"/>
+        <location filename="../src/application/modelhandler.cpp" line="53"/>
         <source>Choose frames to add</source>
         <translation>Seleccione los cuadros a añadir</translation>
     </message>
     <message>
-        <location filename="../src/application/modelhandler.cpp" line="142"/>
+        <location filename="../src/application/modelhandler.cpp" line="143"/>
         <source>Removed the selected frame</source>
         <translation>El cuadro seleccionado se ha quitado</translation>
     </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="216"/>
+        <source>Warning</source>
+        <translation type="unfinished">Advertencia</translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="184"/>
+        <source>You do not have Gimp installed on your system</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="195"/>
+        <source>There is no active frame to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="203"/>
+        <source>The active frame is corrupt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="217"/>
+        <source>Failed to start Gimp!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PreferencesMenu</name>
@@ -1031,112 +1061,112 @@ values exists. Do you want to use this one? (Your old preferences
 <context>
     <name>ToolsMenu</name>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="202"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="210"/>
         <source>FPS chooser</source>
         <translation>Selector de FPS</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="279"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="294"/>
         <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Selector de FPS&lt;/h4&gt; &lt;p&gt;Al cambiar el valor se determina la velocidad a la que se reproduce la animación en el &lt;b&gt;visor de cuadros&lt;/b&gt;.&lt;/p&gt; &lt;p&gt;Para reproducir la animación presione el botón &lt;b&gt;Reproducir animación&lt;/b&gt;.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="203"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="211"/>
         <source>Number of images:</source>
         <translation>Cantidad de imágenes:</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="206"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="214"/>
         <source>Mix</source>
         <translation>Mezcla</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="207"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="215"/>
         <source>Diff</source>
         <translation>Diferencia</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="208"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="216"/>
         <source>Playback</source>
         <translation>Previsualizar</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="222"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="230"/>
         <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Añadir cuadros (CTRL+F)&lt;/h4&gt; &lt;p&gt;Haga clic sobre este botón para &lt;em&gt;añadir&lt;/em&gt; cuadros a la animación &lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="229"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="237"/>
         <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Quitar la selección (Delete)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se quitan&lt;/em&gt; los cuadros seleccionados de la animación.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="236"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="244"/>
         <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Escena nueva (CTRL+E)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se crea&lt;/em&gt; una &lt;em&gt;escena&lt;/em&gt; nueva en la animación.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="243"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="251"/>
         <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Quitar la escena(CTRL+E)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se quita&lt;/em&gt; la escena seleccionada de la animación.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="249"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="257"/>
         <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
         <translation>&lt;h4&gt;Encender/apagar la cámara (C)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón se cambia la cámara entre encendida y apagada&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="257"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="272"/>
         <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Capturar un cuadro (Barra espaciadora)&lt;/h4&gt; &lt;p&gt;Al hacer clic sobre este botón &lt;em&gt;se captura&lt;/em&gt; un cuadro desde la cámara y se coloca en la animación&lt;/p&gt; &lt;p&gt;Esto también puede hacerse presionando la &lt;b&gt;barra espaciadora&lt;/b&gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="268"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="283"/>
         <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Cantidad de imágenes&lt;/h4&gt; &lt;p&gt;Al cambiar este valor en la barra deslizadora se puede especificar cuántas imágenes anteriores de la animación se mezclan sobre la imagen que da la cámara, o si se encuentra en el modo de previsualización: cuántas imágenes reproducir.&lt;/p&gt; &lt;p&gt;Al mezclar las imágenes anteriores con la imagen de la cámara se ve fácilmente la relación que hay entre ellas, haciendo posible lograr movimientos más suaves&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="283"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="298"/>
         <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Reproducir la animación (K, P)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="286"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="301"/>
         <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Detener la animación (K, P)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="289"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="304"/>
         <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Cuadro anterior (J, Izquierda)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="292"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="307"/>
         <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Cuadro siguiente (L, Derecha)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="295"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="310"/>
         <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Escena anterior (I)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="298"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="313"/>
         <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Escena siguiente (O)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="303"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="318"/>
         <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Bucle de animación (CTRL+L)&lt;/h4&gt; &lt;p&gt;Con este botón puede determinar si la animación se reproduce una vez hasta el final, o si se reproduce una y otra vez indefinidamente.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="393"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="408"/>
         <source>Notice</source>
         <translation>Nótese</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="396"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="411"/>
         <source>Playback only currently works when running the grabber 
 as a deamon. Go to the preferences menu (CTRL+P) to switch 
 to running the image grabbing as a deamon.</source>
@@ -1146,24 +1176,29 @@ menú de preferencias (CTRL+P) para hacer que el capturador
 de la imagen corra como un demonio.</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="209"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="217"/>
         <source>Auto</source>
         <translation>Auto</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="213"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="221"/>
         <source>Pr sec</source>
         <translation>Pr sec</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="214"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="222"/>
         <source>Pr min</source>
         <translation>Pr min</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="215"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="223"/>
         <source>Pr hr</source>
         <translation>Pr hr</translation>
     </message>
+    <message>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="264"/>
+        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
